@@ -1,3 +1,4 @@
+import pandas as pd
 from google.cloud import bigquery
 
 from airflow_commons.glossary import COMMA
@@ -20,13 +21,13 @@ from airflow_commons.utils.bigquery.bigquery_utils import (
     get_table_ref,
     get_primitive_column_list,
 )
-from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.bigquery.sql_utils import (
     get_deduplication_source_statement,
     get_merge_sql,
     get_delete_sql,
     get_deduplication_additional_merge_conditions,
 )
+from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.time_utils import get_buffered_timestamp
 
 ARCHIVE_MODES = ["INSERT", "UPSERT"]
@@ -506,3 +507,21 @@ def list_tables(service_account_file: str, project_id: str, dataset_id: str):
         project_id=project_id,
         dataset_id=dataset_id,
     )
+
+
+def insert_to_table_from_dataframe(
+    service_account_file: str, dataset_id: str, table_name: str, data: pd.DataFrame()
+):
+    """
+    Inserts dataframe to the specified table. Returns list of errors for each row
+
+    :param service_account_file: relative location of service account file
+    :param dataset_id: Bigquery dataset id
+    :param table_name: Table name to insert rows
+    :param data: Data to be inserted into the table
+    :return: Sequence[Sequence[Mappings]]: A list with insert errors for each insert chunk.
+    :raises: ValueError: if table's schema is not set
+    """
+    client = connect(service_account_file=service_account_file)
+    table_ref = get_table_ref(client, dataset_id, table_name)
+    return client.insert_rows_from_dataframe(table_ref, data)
