@@ -15,7 +15,7 @@ AVAILABLE_COLUMN_NAMES = ["column_name", "table_name"]
 DEFAULT_TIMEOUT = 60
 DEFAULT_LOCATION = "US"
 DEFAULT_RETURN_TYPE = "dataframe"
-SELECT_RETURN_TYPES = ["dict", "json", "dataframe"]
+SELECT_RETURN_TYPES = ["dict", "json", "dataframe", "pyarrow"]
 PRIMITIVE_DATA_TYPES = [
     "BOOL",
     "BYTES",
@@ -175,7 +175,7 @@ def select(
     """
     Runs a select query and returns results as dataframe
 
-    :param return_type: dataframe, json or dictionary; default is dataframe
+    :param return_type: dataframe, json, dictionary or pyarrow; default is dataframe
     :param client: Client needed for API request
     :param sql: query sql
     :param timeout: job timeout parameter
@@ -196,6 +196,8 @@ def select(
         return result.to_dataframe().to_dict(orient="records")
     elif return_type == "dataframe":
         return result.to_dataframe()
+    elif return_type == "pyarrow":
+        return result.to_arrow()
     else:
         raise ValueError(
             "Invalid requested return type:{}. Acceptable return types are ".format(
